/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2017 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc;

import org.junit.Test;
import org.mariadb.jdbc.internal.util.Utils;

import java.sql.SQLException;

import static org.junit.Assert.assertEquals;


public class UtilTest {
    @Test
    public void escape() throws SQLException {
        String[] inputs = new String[]{
                "select {fn timestampdiff(SQL_TSI_HOUR, {fn convert('SQL_', SQL_INTEGER)})}",
                "{call foo({fn now()})}",
                "{?=call foo({fn now()})}",
                "SELECT 'David_' LIKE 'David|_' {escape '|'}",
                "select {fn dayname ({fn abs({fn now()})})}",
                "{d '1997-05-24'}",
                "{d'1997-05-24'}",
                "{t '10:30:29'}",
                "{t'10:30:29'}",
                "{ts '1997-05-24 10:30:29.123'}",
                "{ts'1997-05-24 10:30:29.123'}",
                "'{string data with { or } will not be altered'",
                "--  Also note that you can safely include { and } in comments"
        };
        String[] outputs = new String[]{
                "select timestampdiff(HOUR, convert('SQL_', INTEGER))",
                "call foo(now())",
                "?=call foo(now())",
                "SELECT 'David_' LIKE 'David|_' escape '|'",
                "select dayname (abs(now()))",
                "'1997-05-24'",
                "'1997-05-24'",
                "'10:30:29'",
                "'10:30:29'",
                "'1997-05-24 10:30:29.123'",
                "'1997-05-24 10:30:29.123'",
                "'{string data with { or } will not be altered'",
                "--  Also note that you can safely include { and } in comments"
        };
        for (int i = 0; i < inputs.length; i++) {
            assertEquals(Utils.nativeSql(inputs[i], false), outputs[i]);
        }
    }
}